# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Inventory Service."""

__version__ = "0.1.0"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .admin_create_inventory__71b514 import AdminCreateInventoryConfiguration
from .admin_delete_inventory__38371e import AdminDeleteInventoryConfiguration
from .admin_get_inventory_con_709281 import AdminGetInventoryConfiguration
from .admin_list_inventory_co_67d862 import AdminListInventoryConfigurations
from .admin_list_inventory_co_67d862 import (
    SortByEnum as AdminListInventoryConfigurationsSortByEnum,
)
from .admin_update_inventory__e10746 import AdminUpdateInventoryConfiguration
