# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Iam Service."""

__version__ = "7.10.0"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .admin_add_country_blacklist_v3 import AdminAddCountryBlacklistV3
from .admin_get_country_blacklist_v3 import AdminGetCountryBlacklistV3
from .admin_get_country_list_v3 import AdminGetCountryListV3
from .public_get_country_list_v3 import PublicGetCountryListV3
